pub struct RecordUpdate {
pub record_id: ValidName,
pub meta: Option<ValidMeta>,
pub components: Vec<Component>,
pub start_time: Option<DateTime<Utc>>,
pub stop_time: DateTime<Utc>,
}Expand description
RecordUpdate represents a single accountable unit that is used to set the stop_time of a
Record.
Initially, records are added to Auditor by pushing a RecordAdd, where the stop_time field
is optional. To later set the stop_time of the record, push a RecordUpdate with the same
record_id to auditor.
Use the constructor to build a new record.
Note
All strings must not include the characters /()"<>\{}.
When created using the constructor, the record is already valid in terms of all checks that Auditor performs when receiving it.
Currently, only the stop_time can be updated.
Setting other fields such as meta or components has no effect.
Examples
Create a valid record
use chrono::{DateTime, TimeZone, Utc};
let stop_time: DateTime<Utc> = Utc.with_ymd_and_hms(2023, 1, 1, 12, 0, 0).unwrap();
let record = RecordUpdate::new("123456", HashMap::new(), Vec::new(), stop_time)?;Fields
record_id: ValidNameUnique identifier of the record.
meta: Option<ValidMeta>Meta information, a collection of key value pairs in the form of String -> Vec<String>.
components: Vec<Component>List of components that are accounted for.
start_time: Option<DateTime<Utc>>Start time of the record.
stop_time: DateTime<Utc>Stop time of the record.
Implementations